function isPlainObject(value: unknown): value is Record<string | number, unknown> {
    if (!value) return false;
    return [undefined, Object as any].includes(value.constructor);
}

export default function clone<T>(value: T): T {
    if (typeof value !== "object" || value === null) return value;
    else if (Array.isArray(value)) {
        return value.map(clone) as T;
    } else if (isPlainObject(value)) {
        return Object.fromEntries(Object.entries(value).map(([key, value]) => [key, clone(value)])) as T;
    } else {
        console.warn(`Cannot clone ${value}!`);
        return value;
    }
}
