import { LobbyClient } from "boardgame.io/client";
import { LOBBY_SERVER } from "../consts.js";
import { Show, createResource, createSignal } from "solid-js";
import classes from "./Connect.module.css";
import Status from "./Status.tsx";
import { DEFAULT_SETUP_DATA, type SetupData } from "../game.ts";

export type ConnectProps = {
    gameName: string,
    matchID: string,
    setCredentials: (credentials: string) => void,
    setPlayerID: (playerID: string) => void,
    setSpectating: (spectating: boolean) => void,
};

export default function Connect(props: ConnectProps) {
    const client = new LobbyClient({
        server: LOBBY_SERVER
    });
    const [name, setName] = createSignal<string>("");

    const [match] = createResource(() => client.getMatch(props.gameName, props.matchID));

    return <div class={classes.modal}>
        <div class={classes.card}>
            <h2>Join game</h2>

            <div class={classes.inputs}>
                <input type="text" value={name()} onChange={(event) => setName(event.currentTarget.value)} placeholder="Your name" />
                <button
                    onClick={() => {
                        client.joinMatch(
                            props.gameName,
                            props.matchID,
                            {
                                playerName: name() || `Anonymous`,
                            }
                        ).then((res) => {
                            props.setPlayerID(res.playerID);
                            props.setCredentials(res.playerCredentials);
                        }).catch(console.error);
                    }}
                    disabled={match()?.players.every((player) => !!player.name) ?? false}
                >
                    Join game
                </button>
                <button onClick={() => props.setSpectating(true)}>Spectate</button>
            </div>

            <Status gameName={props.gameName} matchID={props.matchID} />

            <Show when={(match()?.setupData as SetupData)}>
                {(setupData) => {
                    return (<div class={classes["setup-data"]}>
                        <h3>Game settings:</h3>
                        <ul>
                            <li>Size: {setupData().size ?? DEFAULT_SETUP_DATA.size}</li>
                            <li>Initial resources: {setupData().initialResources ?? DEFAULT_SETUP_DATA.initialResources}</li>
                        </ul>
                    </div>);
                }}
            </Show>
        </div>
    </div>;
}
