import { Match, Switch, createSignal } from "solid-js";
import Game from "./Game.js";
import Connect from "./Connect.tsx";
import { AcrossTheHex } from "../game.ts";

export type MultiplayerProps = {
    matchID: string,
    debug: boolean,
};

export default function Multiplayer(props: MultiplayerProps) {
    const [credentials, setCredentials] = createSignal<string>();
    const [playerID, setPlayerID] = createSignal<string>();
    const [spectating, setSpectating] = createSignal(false);


    return (
        <Switch>
            <Match when={playerID() && credentials()}>
                {(_) => {
                    return <Game
                        playerID={playerID()!}
                        credentials={credentials()!}
                        matchID={props.matchID}
                        debug={props.debug}
                    />;
                }}
            </Match>
            <Match when={!spectating()}>
                <Connect
                    gameName={AcrossTheHex.name!}
                    matchID={props.matchID}
                    setCredentials={setCredentials}
                    setPlayerID={setPlayerID}
                    setSpectating={setSpectating}
                />
            </Match>
            <Match when={spectating()}>
                {(_) => {
                    return <Game
                        matchID={props.matchID}
                        debug={props.debug}
                    />;
                }}
            </Match>
        </Switch>
    );
}
