import { LobbyClient } from "boardgame.io/client"
import { LOBBY_SERVER, PLAYER_COLORS } from "../consts.ts";
import { For, Show, createEffect, createResource, onCleanup } from "solid-js";
import classes from "./Status.module.css";

export type StatusProps = {
    gameName: string,
    matchID: string,
}

export default function Status(props: StatusProps) {
    const client = new LobbyClient({
        server: LOBBY_SERVER
    });

    const [match, actions] = createResource(() => client.getMatch(props.gameName, props.matchID));

    createEffect(() => {
        setTimeout(() => {
            actions.refetch();
        }, 1000);

        const interval = setInterval(() => {
            actions.refetch();
        }, 10000);

        onCleanup(() => clearInterval(interval));
    });

    return <ul class={classes.users}>
        <For each={match()?.players} fallback={<li><i>Loading...</i></li>}>
            {(player, index) => {
                return <li data-index={index()} class={player.isConnected ? classes.connected : classes["logged-out"]}>
                    <div class={classes["player-icon"]} style={{
                        "--color": PLAYER_COLORS[player.id % PLAYER_COLORS.length]
                    }}></div>
                    <Show when={player.name} fallback={<i>No player</i>}>{player.name}</Show>
                </li>;
            }}
        </For>
    </ul>;
}
